==========
Data Cliff
==========


.. image:: https://img.shields.io/pypi/v/data_cliff.svg
        :target: https://pypi.python.org/pypi/data_cliff

.. image:: https://img.shields.io/travis/ruizdesotto/data_cliff.svg
        :target: https://travis-ci.com/ruizdesotto/data_cliff

.. image:: https://readthedocs.org/projects/data-cliff/badge/?version=latest
        :target: https://data-cliff.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/ruizdesotto/data_cliff/shield.svg
     :target: https://pyup.io/repos/github/ruizdesotto/data_cliff/
     :alt: Updates



CLI tool to show differences on text data tracked by dvc.


* Free software: Apache Software License 2.0
* Documentation: https://data-cliff.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
